@@ -1,7 +1,7 @@
-#!/usr/bin/env python
+﻿#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 __author__ = "Mikhail Fedosov (tbs.micle@gmail.com)"
-__version__ = "0.1.4"
+__version__ = "0.1.5"
 
 # http://code.activestate.com/recipes/577708-check-for-package-updates-on-pypi-works-best-in-pi/
 # http://stackoverflow.com/questions/287871/print-in-terminal-with-colors-using-python
@@ -9,11 +9,19 @@ __version__ = "0.1.4"
 import pip
 import sys
 import socket
-import xmlrpclib
 from multiprocessing import Pool
+if sys.version_info < (3, 0):
+	from xmlrpclib import ServerProxy
+else:
+	from xmlrpc.client import ServerProxy
+
+if sys.version_info < (3, 0):
+	reload(sys)
+	sys.setdefaultencoding("utf-8")
+else:
+	# http://stackoverflow.com/questions/3828723/why-we-need-sys-setdefaultencodingutf-8-in-a-py-script
+	pass
 
-reload(sys)
-sys.setdefaultencoding("utf-8")
 
 class colors:
 	""" Colored terminal text
@@ -57,7 +65,7 @@ if sys.platform == "win32":
 	symbols.simplify()
 
 def check_package(dist):
-	pypi = xmlrpclib.ServerProxy("http://pypi.python.org/pypi")
+	pypi = ServerProxy("http://pypi.python.org/pypi")
 
 	try:
 		available = pypi.package_releases(dist.project_name)
